# frozen_string_literal: true

require 'happymapper'
require_relative './node'
require_relative './length'
require_relative './price'
require_relative './rixml_type/normalized_string'
require_relative './rixml_type/yes_no_boolean'

module RixmlDocument
  class Resource < Node
    include HappyMapper
    tag 'Resource'

    has_one :length, Length, tag: 'Length', xpath: './'
    has_one :price, Price, tag: 'Price', xpath: './'

    attribute :resource_id, RixmlType::NormalizedString, tag: 'resourceID'
    attribute :language, RixmlType::NormalizedString, tag: 'language'
    attribute :primary_indicator, RixmlType::YesNoBoolean, tag: 'primaryIndicator'
    attribute :size_in_bytes, Integer, tag: 'sizeInBytes'

    element :mime_type, String, tag: 'MIMEType'
    element :name, String, tag: 'Name'
    element :url, String, tag: 'URL'

    def number_of_pages
      return if length.nil?

      length.value if length.pages?
    end
  end
end
